%  Program: progSA5e.m
%  Description: Generates a plot for f(x_0 + alpha*d_0) as a function
%  of alpha over interval [0, 6.2832] for Prob.SA.5e. 
%  Input:
%        x0: a point given by [-pi -pi]' 
%        d0: a search direction given by [1 0.85]'
%     alpha: a scalar obtained using the inexact line search algorithm 
%            (Algorithm 4.6)
%  Output:
%     a plot for f(x_0 + alpha*d_0) as a function of alpha over interval 
%     [0, 6.2832].
%  To Run: Execute the commands:
%      x0 = [x1 x2]' % e.g., x0=[-pi -pi]'
%      d0 = [d1 d2]' % e.g., d0=[1 0.85]'
%      alpha = inex_lsearch(x0,d0,'progSA5c1','progSA5c2'); % alpha = 2.7852
%      progSA5e
%  =====================================================================
disp(' ')
disp('Program progSA5e')
a = 0:6.2832/599:6.2832;
for i = 1:600,
    xw = x0 + a(i)*d0; 
    f1(i) = progSA5c1(xw); 
end
figure(3)
plot(a,f1,'color','blue','linewidth',1.5)
axis([0 a(600) -20 60])
hold on
plot(a,0*f1,'color','black')
is = round(alpha*599/6.2832);
aa = a(is);
plot(aa,0,'x','color','black')
plot([aa aa],[0 f1(is)],'--','color','black')
xlabel('\alpha','FontName','Times','FontSize',13)
ylabel('\itf(\itx_0+\alpha\itd_0)','FontName','Times','FontSize',13)
grid
hold off
clear a aa f1 i is xw