%  Program: progSA8b.m
%  Description: Implements the steepest-descent method (Algorithm 5.1) 
%  for Problem SA.8b using Fletcher's inexact line search 
%  (Algorithm 4.6).
%  Theory: See Practical Optimization Sec. 5.2.
%  Input:    
%      x0: initial point
%    epsi: optimization tolerance
%  Output:   
%      xs: solution point.
%      fs: objective function evaluated at xs.
%       k: number of iterations performed.
%  Example: 
%  Find the minimum of 
%  f(x) = (x1-4*x2)^4 + 12*(x3-x4)^4 + 3*(x2-10*x3)^2 + 55*(x1-2*x4)^2
%  by using the steepest-descent method.
%  Solution: 
%  Execute the commands:
%     x0 = [1 -1 -1 1]'
%     epsi = 1e-6
%     [xs,fs,k] = progSA8b(x0,epsi)
%  ===================================================================
function [xs,fs,k] = progSA8b(x0,epsi)
k = 1;
xk = x0;
gk = progSA8b2(xk);
dk = -gk;
ak = inex_lsearch(xk,dk,'progSA8b1','progSA8b2');
adk = ak*dk;
er = norm(adk);
while er >= epsi,
   xk = xk + adk;
   gk = progSA8b2(xk);
   dk = -gk;
   ak = inex_lsearch(xk,dk,'progSA8b1','progSA8b2');
   adk = ak*dk;
   er = norm(adk);
   k = k + 1;
end
format long
disp('Minimum point:')
xs = xk + adk
disp('Minimum of objective function:')
fs = progSA8b1(xs)
format short
disp('Number of iterations performed:')
k