%  Program: progSA8c.m
%  Description: Implements the Gauss-Newton method (Algorithm 5.5) 
%  for Problem SA.8c using Fletcher's inexact line search 
%  (Algorithm 4.6).
%  Theory: See Practical Optimization Sec. 5.4.
%  Input:    
%      x0: initial point
%    epsi: optimization tolerance
%  Output:   
%      xs: solution point.
%      fs: objective function evaluated at xs.
%       k: number of iterations performed.
%  Example: 
%  Find the minimum of 
%  f(x) = (x1-4*x2)^4 + 12*(x3-x4)^4 + 3*(x2-10*x3)^2 + 55*(x1-2*x4)^2
%  by using the Gauss-Newton method.
%  Solution: 
%  Execute the commands:
%     x0 = [1 -1 -1 1]'
%     epsi = 1e-6
%     [xs,fs,k] = progSA8c(x0,epsi)
%  ====================================================================
function [xs,fs,k] = progSA8c(x0,epsi)
x = x0(:);
k = 1;
xk = x0;
Jk = progSA8c2(xk);
gk = progSA8c1(xk);
Hk = 2*Jk'*Jk;
dk = -inv(Hk)*gk;
ak = inex_lsearch(xk,dk,'progSA8b1','progSA8c1');
adk = ak*dk;
er = norm(adk);
while er > epsi,
  xk = xk + adk;
  Jk = progSA8c2(xk);
  gk = progSA8c1(xk);
  Hk = 2*Jk'*Jk;
  dk = -inv(Hk)*gk;
  ak = inex_lsearch(xk,dk,'progSA8b1','progSA8c1');
  adk = ak*dk;
  er = norm(adk);
  k = k + 1;
end
format long
disp('Minimum point:')
xs = xk + adk
disp('Minimum of objective function:')
fs = progSA8b1(xs)
format short
disp('Number of iterations:')
k